==> neatui-1.0.9.tgz: package/es/maptag/MapTag.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

/**
 * maptag.jsx
 *
 * @Author: zhangce
 * @Date: 17/8/23 上午11:36
 */
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Close from '../icons/internals/Close';
/**
 * MapTag
 * */

var MapTag =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(MapTag, _React$PureComponent);

  function MapTag(props, context) {
    var _this;

    _classCallCheck(this, MapTag);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(MapTag).call(this, props, context));

    _defineProperty(_assertThisInitialized(_this), "onDelete", function (e, uuid) {
      var _this$props = _this.props,
          onDelete = _this$props.onDelete,
          disabled = _this$props.disabled,
          transitionDuration = _this$props.transitionDuration,
          afterClose = _this$props.afterClose,
          onClose = _this$props.onClose;
      var handleClose = onDelete || onClose;

      if (handleClose && !disabled) {
        handleClose(uuid);
      }

      if (e.defaultPrevented || disabled) {
        return;
      }

      _this.setState({
        closing: true
      });

      setTimeout(function () {
        if (_this.unMount) {
          _this.setState({
            isClosed: true
          });
        }

        if (afterClose) {
          afterClose();
        }
      }, transitionDuration);
    });

    _defineProperty(_assertThisInitialized(_this), "showInput", function (e) {
      var onClick = _this.props.onClick;

      if (onClick) {
        onClick(e);
      }

      _this.setState(function (state) {
        return {
          showInput: !state.showInput
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onInputBlur", function () {
      var _this$props2 = _this.props,
          onCreate = _this$props2.onCreate,
          onInput = _this$props2.onInput;
      var inputValue = _this.state.inputValue;
      var showInput = false;

      if (inputValue === '') {
        showInput = false;
      } else if (onCreate) {
        showInput = !onCreate(inputValue);
      } else if (onInput) {
        showInput = !onInput(inputValue);
      }

      if (!showInput) {
        _this.setState({
          showInput: showInput,
          inputValue: ''
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      _this.setState({
        inputValue: e.target.value
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyDown", function (e) {
      var enterKey = _this.props.enterKey;
      var charCode = e.which ? e.which : e.keyCode;

      if (enterKey.indexOf(charCode) !== -1) {
        e.preventDefault();

        _this.onInputBlur();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "getInputElement", function (el) {
      _this.createInput = el;
    });

    _this.state = {
      isClosed: false,
      showInput: false,
      inputValue: '',
      closing: false
    };
    return _this;
  }

  _createClass(MapTag, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var showInput = this.state.showInput;

      if (showInput) {
        this.createInput && this.createInput.focus();
      }
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.unMount = true;
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this,
          _classNames;

      var _this$state = this.state,
          isClosed = _this$state.isClosed,
          showInput = _this$state.showInput,
          inputValue = _this$state.inputValue,
          closing = _this$state.closing;

      var _this$props3 = this.props,
          prefixCls = _this$props3.prefixCls,
          children = _this$props3.children,
          closable = _this$props3.closable,
          isAddableMapTag = _this$props3.isAddableMapTag,
          input = _this$props3.input,
          className = _this$props3.className,
          onClick = _this$props3.onClick,
          onInput = _this$props3.onInput,
          onCreate = _this$props3.onCreate,
          onDelete = _this$props3.onDelete,
          type = _this$props3.type,
          disabled = _this$props3.disabled,
          afterClose = _this$props3.afterClose,
          enterKey = _this$props3.enterKey,
          title = _this$props3.title,
          color = _this$props3.color,
          size = _this$props3.size,
          uuid = _this$props3.uuid,
          transitionDuration = _this$props3.transitionDuration,
          other = _objectWithoutProperties(_this$props3, ["prefixCls", "children", "closable", "isAddableMapTag", "input", "className", "onClick", "onInput", "onCreate", "onDelete", "type", "disabled", "afterClose", "enterKey", "title", "color", "size", "uuid", "transitionDuration"]);

      var closeBtn = closable && !isAddableMapTag && !input ? React.createElement(Close, {
        className: "".concat(prefixCls, "-icon-close"),
        size: "small",
        onClick: function onClick(e) {
          _this2.onDelete(e, uuid);
        }
      }) : null;
      var classString = classNames(prefixCls, (_classNames = {}, _defineProperty(_classNames, "".concat(prefixCls, "-").concat(color), color), _defineProperty(_classNames, "".concat(prefixCls, "-disabled"), disabled), _defineProperty(_classNames, "".concat(prefixCls, "-create"), isAddableMapTag || input), _defineProperty(_classNames, "".concat(prefixCls, "-create-active"), (isAddableMapTag || input) && showInput), _defineProperty(_classNames, "".concat(prefixCls, "-closing"), closing), _classNames), "".concat(prefixCls, "-").concat(size), className);
      var maptag = isClosed ? null : React.createElement("div", _extends({
        className: classString,
        onClick: isAddableMapTag || input ? this.showInput : onClick
      }, other), (isAddableMapTag || input) && showInput ? React.createElement("input", {
        disabled: disabled,
        className: "".concat(prefixCls, "-input"),
        ref: this.getInputElement,
        value: inputValue,
        onChange: this.handleChange,
        onKeyDown: this.onKeyDown,
        onBlur: this.onInputBlur
      }) : React.createElement("span", {
        className: "".concat(prefixCls, "-content"),
        title: title
      }, children), closeBtn);
      return maptag;
    }
  }]);

  return MapTag;
}(React.PureComponent);

_defineProperty(MapTag, "propTypes", {
  /**
   * 类前缀
   * */
  prefixCls: PropTypes.string,

  /**
   * 类名
   * */
  className: PropTypes.string,

  /**
   * 标签类型
   * */
  color: PropTypes.string,

  /**
   * 是否禁用
   * */
  disabled: PropTypes.bool,

  /**
   * 是否可关闭标签
   * */
  closable: PropTypes.bool,

  /**
   * 标签是否为创建标签
   * */
  input: PropTypes.bool,

  /**
   * 删除动画结束
   * */
  afterClose: PropTypes.func,

  /**
   * 点击删除标签回调
   * */
  onClose: PropTypes.func,

  /**
   * 点击标签回调
   * */
  onClick: PropTypes.func,

  /**
   * 添加标签回调
   * */
  onCreate: PropTypes.func,

  /**
   * 创建新标签的键值
   * */
  enterKey: PropTypes.array,

  /**
   * 提示信息
   * */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  transitionDuration: PropTypes.number
});

_defineProperty(MapTag, "defaultProps", {
  prefixCls: 'ne-maptag',
  closable: false,
  size: 'medium',
  enterKey: [13],
  transitionDuration: 200
});

export default MapTag;

==> neatui-1.0.23.tgz: package/es/maptag/MapTag.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
var _excluded = ["prefixCls", "children", "closable", "isAddableMapTag", "input", "className", "onClick", "onInput", "onCreate", "onDelete", "type", "disabled", "afterClose", "enterKey", "title", "color", "size", "uuid", "transitionDuration"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * maptag.jsx
 *
 * @Author: zhangce
 * @Date: 17/8/23 上午11:36
 */
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Close from '../icons/internals/Close';
/**
 * MapTag
 * */

var MapTag = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(MapTag, _React$PureComponent);

  var _super = _createSuper(MapTag);

  function MapTag(props, context) {
    var _this;

    _classCallCheck(this, MapTag);

    _this = _super.call(this, props, context);

    _defineProperty(_assertThisInitialized(_this), "onDelete", function (e, uuid) {
      var _this$props = _this.props,
          onDelete = _this$props.onDelete,
          disabled = _this$props.disabled,
          transitionDuration = _this$props.transitionDuration,
          afterClose = _this$props.afterClose,
          onClose = _this$props.onClose;
      var handleClose = onDelete || onClose;

      if (handleClose && !disabled) {
        handleClose(uuid);
      }

      if (e.defaultPrevented || disabled) {
        return;
      }

      _this.setState({
        closing: true
      });

      setTimeout(function () {
        if (_this.unMount) {
          _this.setState({
            isClosed: true
          });
        }

        if (afterClose) {
          afterClose();
        }
      }, transitionDuration);
    });

    _defineProperty(_assertThisInitialized(_this), "showInput", function (e) {
      var onClick = _this.props.onClick;

      if (onClick) {
        onClick(e);
      }

      _this.setState(function (state) {
        return {
          showInput: !state.showInput
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onInputBlur", function () {
      var _this$props2 = _this.props,
          onCreate = _this$props2.onCreate,
          onInput = _this$props2.onInput;
      var inputValue = _this.state.inputValue;
      var showInput = false;

      if (inputValue === '') {
        showInput = false;
      } else if (onCreate) {
        showInput = !onCreate(inputValue);
      } else if (onInput) {
        showInput = !onInput(inputValue);
      }

      if (!showInput) {
        _this.setState({
          showInput: showInput,
          inputValue: ''
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      _this.setState({
        inputValue: e.target.value
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyDown", function (e) {
      var enterKey = _this.props.enterKey;
      var charCode = e.which ? e.which : e.keyCode;

      if (enterKey.indexOf(charCode) !== -1) {
        e.preventDefault();

        _this.onInputBlur();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "getInputElement", function (el) {
      _this.createInput = el;
    });

    _this.state = {
      isClosed: false,
      showInput: false,
      inputValue: '',
      closing: false
    };
    return _this;
  }

  _createClass(MapTag, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var showInput = this.state.showInput;

      if (showInput) {
        this.createInput && this.createInput.focus();
      }
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.unMount = true;
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this,
          _classNames;

      var _this$state = this.state,
          isClosed = _this$state.isClosed,
          showInput = _this$state.showInput,
          inputValue = _this$state.inputValue,
          closing = _this$state.closing;

      var _this$props3 = this.props,
          prefixCls = _this$props3.prefixCls,
          children = _this$props3.children,
          closable = _this$props3.closable,
          isAddableMapTag = _this$props3.isAddableMapTag,
          input = _this$props3.input,
          className = _this$props3.className,
          onClick = _this$props3.onClick,
          onInput = _this$props3.onInput,
          onCreate = _this$props3.onCreate,
          onDelete = _this$props3.onDelete,
          type = _this$props3.type,
          disabled = _this$props3.disabled,
          afterClose = _this$props3.afterClose,
          enterKey = _this$props3.enterKey,
          title = _this$props3.title,
          color = _this$props3.color,
          size = _this$props3.size,
          uuid = _this$props3.uuid,
          transitionDuration = _this$props3.transitionDuration,
          other = _objectWithoutProperties(_this$props3, _excluded);

      var closeBtn = closable && !isAddableMapTag && !input ? /*#__PURE__*/React.createElement(Close, {
        className: "".concat(prefixCls, "-icon-close"),
        size: "small",
        onClick: function onClick(e) {
          _this2.onDelete(e, uuid);
        }
      }) : null;
      var classString = classNames(prefixCls, (_classNames = {}, _defineProperty(_classNames, "".concat(prefixCls, "-").concat(color), color), _defineProperty(_classNames, "".concat(prefixCls, "-disabled"), disabled), _defineProperty(_classNames, "".concat(prefixCls, "-create"), isAddableMapTag || input), _defineProperty(_classNames, "".concat(prefixCls, "-create-active"), (isAddableMapTag || input) && showInput), _defineProperty(_classNames, "".concat(prefixCls, "-closing"), closing), _classNames), "".concat(prefixCls, "-").concat(size), className);
      var maptag = isClosed ? null : /*#__PURE__*/React.createElement("div", _extends({
        className: classString,
        onClick: isAddableMapTag || input ? this.showInput : onClick
      }, other), (isAddableMapTag || input) && showInput ? /*#__PURE__*/React.createElement("input", {
        disabled: disabled,
        className: "".concat(prefixCls, "-input"),
        ref: this.getInputElement,
        value: inputValue,
        onChange: this.handleChange,
        onKeyDown: this.onKeyDown,
        onBlur: this.onInputBlur
      }) : /*#__PURE__*/React.createElement("span", {
        className: "".concat(prefixCls, "-content"),
        title: title
      }, children), closeBtn);
      return maptag;
    }
  }]);

  return MapTag;
}(React.PureComponent);

_defineProperty(MapTag, "propTypes", {
  /**
   * 类前缀
   * */
  prefixCls: PropTypes.string,

  /**
   * 类名
   * */
  className: PropTypes.string,

  /**
   * 标签类型
   * */
  color: PropTypes.string,

  /**
   * 是否禁用
   * */
  disabled: PropTypes.bool,

  /**
   * 是否可关闭标签
   * */
  closable: PropTypes.bool,

  /**
   * 标签是否为创建标签
   * */
  input: PropTypes.bool,

  /**
   * 删除动画结束
   * */
  afterClose: PropTypes.func,

  /**
   * 点击删除标签回调
   * */
  onClose: PropTypes.func,

  /**
   * 点击标签回调
   * */
  onClick: PropTypes.func,

  /**
   * 添加标签回调
   * */
  onCreate: PropTypes.func,

  /**
   * 创建新标签的键值
   * */
  enterKey: PropTypes.array,

  /**
   * 提示信息
   * */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  transitionDuration: PropTypes.number
});

_defineProperty(MapTag, "defaultProps", {
  prefixCls: 'ne-maptag',
  closable: false,
  size: 'medium',
  enterKey: [13],
  transitionDuration: 200
});

export default MapTag;
